# 玲儿

自用 QQ 机器人。

## 功能

- Bilibili 用户监控，参见：[nonebot-plugin-bam]

## 使用

```bash
pip install qqbot-linger
cd /a/path/you/want/store/config/and/database
vim .env # edit this file, see `.env.sample file` for a example

# Start cqhttp server
# like go-cqhttp, cqhttp-mirai etc

linger # start the bot
```

## 截图

以后再弄。

## LICENSE

Unlicense.

[nonebot-plugin-bam]: https://github.com/7sDream/nonebot_plugin_bam
